summaryrefslogtreecommitdiff
path: root/src/perl/perl-sources.h
diff options
context:
space:
mode:
authorTimo Sirainen <cras@irssi.org>2001-12-06 17:17:40 +0000
committercras <cras@dbcabf3a-b0e7-0310-adc4-f8d773084564>2001-12-06 17:17:40 +0000
commit31dcd8258f8f52c065e4297f7abecc5dd0a7d0a2 (patch)
treefc3cdc763159ad896422775addb1a763d53536ee /src/perl/perl-sources.h
parent9dd46372ff722a54d70ae383b79542f6d3c60200 (diff)
downloadirssi-31dcd8258f8f52c065e4297f7abecc5dd0a7d0a2.zip
Irssi::signal_add(), Irssi::timeout_add(), Irssi::input_add() and their
variants now also allow use of code references. git-svn-id: http://svn.irssi.org/repos/irssi/trunk@2199 dbcabf3a-b0e7-0310-adc4-f8d773084564
Diffstat (limited to 'src/perl/perl-sources.h')
-rw-r--r--src/perl/perl-sources.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/perl/perl-sources.h b/src/perl/perl-sources.h
index e61004db..db165689 100644
--- a/src/perl/perl-sources.h
+++ b/src/perl/perl-sources.h
@@ -1,12 +1,12 @@
#ifndef __PERL_SOURCES_H
#define __PERL_SOURCES_H
-int perl_timeout_add(int msecs, const char *func, SV *data);
-int perl_input_add(int source, int condition, const char *func, SV *data);
+int perl_timeout_add(int msecs, SV *func, SV *data);
+int perl_input_add(int source, int condition, SV *func, SV *data);
void perl_source_remove(int tag);
-/* remove all sources used by package */
-void perl_source_remove_package(const char *package);
+/* remove all sources used by script */
+void perl_source_remove_script(PERL_SCRIPT_REC *script);
void perl_sources_start(void);
void perl_sources_stop(void);